InternetExplorerCustomProxyLauncher (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.browserlaunchers
Class InternetExplorerCustomProxyLauncher

    java.lang.Object
      org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher
          org.openqa.selenium.server.browserlaunchers.InternetExplorerCustomProxyLauncher

All Implemented Interfaces:
  BrowserLauncher

Direct Known Subclasses:
  ProxyInjectionInternetExplorerCustomProxyLauncher

    public class InternetExplorerCustomProxyLauncher

extends AbstractBrowserLauncher

Field Summary
`protected boolean` | `changeMaxConnections`
`protected boolean` | `customPACappropriate`
`protected WindowsProxyManager` | `wpm`

Fields inherited from class org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher
`browserConfigurationOptions, sessionId`

Constructor Summary
`InternetExplorerCustomProxyLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, BrowserInstallation browserInstallation)`
`InternetExplorerCustomProxyLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`

Method Summary
`protected void` | `changeRegistrySettings()`
`void` | `close()` Stop (kill) the browser process
`java.lang.Process` | `getProcess()` Returns a process if there is an associated one running with this browser launcher (this is not required to be implementd).
`void` | `launch(java.lang.String url)`
`static void` | `main(java.lang.String[] args)`
`static void` | `setChangeMaxConnections(boolean changeMaxConnections)`

Methods inherited from class org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher
`getConfiguration, getPort, launchHTMLSuite, launchRemoteSession`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Field Detail

### customPACappropriate

    protected boolean customPACappropriate

### wpm

    protected WindowsProxyManager wpm

### changeMaxConnections

    protected boolean changeMaxConnections

Constructor Detail

### InternetExplorerCustomProxyLauncher

    public InternetExplorerCustomProxyLauncher(BrowserConfigurationOptions browserOptions,
                                               RemoteControlConfiguration configuration,
                                               java.lang.String sessionId,
                                               java.lang.String browserLaunchLocation)

### InternetExplorerCustomProxyLauncher

    public InternetExplorerCustomProxyLauncher(BrowserConfigurationOptions browserOptions,
                                               RemoteControlConfiguration configuration,
                                               java.lang.String sessionId,
                                               BrowserInstallation browserInstallation)

Method Detail

### changeRegistrySettings

    protected void changeRegistrySettings()
                                   throws java.io.IOException

  Throws:
    `java.io.IOException`

### launch

    public void launch(java.lang.String url)

  Specified by:
    `launch` in class `AbstractBrowserLauncher`

### close

    public void close()

  Description copied from interface: `BrowserLauncher`
  Stop (kill) the browser process

### getProcess

    public java.lang.Process getProcess()

  Description copied from interface: `BrowserLauncher`
  Returns a process if there is an associated one running with this browser launcher (this is not required to be implementd).

  Returns:
    a handle to a process if one is available, or null if one is not available or if no browser is running

### main

    public static void main(java.lang.String[] args)

### setChangeMaxConnections

    public static void setChangeMaxConnections(boolean changeMaxConnections)

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.